@@ -38,9 +38,7 @@
 # include <unistd.h>
 #endif
 
-#ifdef HAVE_SYS_UIO_H
 #include <sys/uio.h>
-#endif
 
 #include "gsocket.h"
 #include "gcancellable.h"
@@ -305,8 +303,7 @@ g_socket_details_from_fd (GSocket *socket)
   int value;
   int errsv;
 #ifdef G_OS_WIN32
-  /* See bug #611756 */
-  BOOL bool_val = FALSE;
+  BOOL bool_val;
 #else
   int bool_val;
 #endif
@@ -389,14 +386,7 @@ g_socket_details_from_fd (GSocket *socket)
   if (getsockopt (fd, SOL_SOCKET, SO_KEEPALIVE,
 		  (void *)&bool_val, &optlen) == 0)
     {
-#ifndef G_OS_WIN32
-      /* Experimentation indicates that the SO_KEEPALIVE value is
-       * actually a char on Windows, even if documentation claims it
-       * to be a BOOL which is a typedef for int. So this g_assert()
-       * fails. See bug #611756.
-       */
       g_assert (optlen == sizeof bool_val);
-#endif
       socket->priv->keepalive = !!bool_val;
     }
   else
@@ -614,12 +604,6 @@ g_socket_finalize (GObject *object)
     g_socket_close (socket, NULL);
 
 #ifdef G_OS_WIN32
-  if (socket->priv->event != WSA_INVALID_EVENT)
-    {
-      WSACloseEvent (socket->priv->event);
-      socket->priv->event = WSA_INVALID_EVENT;
-    }
-
   g_assert (socket->priv->requested_conditions == NULL);
 #endif
 
@@ -1311,7 +1295,7 @@ g_socket_bind (GSocket         *socket,
  *
  * Returns: %TRUE if this socket can be used with IPv4.
  *
- * Since: 2.22
+ * Since: 2.22.
  **/
 gboolean
 g_socket_speaks_ipv4 (GSocket *socket)
@@ -1346,7 +1330,6 @@ g_socket_speaks_ipv4 (GSocket *socket)
 /**
  * g_socket_accept:
  * @socket: a #GSocket.
- * @cancellable: a %GCancellable or %NULL
  * @error: #GError for error reporting, or %NULL to ignore.
  *
  * Accept incoming connections on a connection-based socket. This removes
@@ -1367,7 +1350,6 @@ g_socket_speaks_ipv4 (GSocket *socket)
  */
 GSocket *
 g_socket_accept (GSocket       *socket,
-		 GCancellable  *cancellable,
 		 GError       **error)
 {
   GSocket *new_socket;
@@ -1382,7 +1364,7 @@ g_socket_accept (GSocket       *socket,
     {
       if (socket->priv->blocking &&
 	  !g_socket_condition_wait (socket,
-				    G_IO_IN, cancellable, error))
+				    G_IO_IN, NULL, error))
 	return NULL;
 
       if ((ret = accept (socket->priv->fd, NULL, 0)) < 0)
@@ -1458,7 +1440,6 @@ g_socket_accept (GSocket       *socket,
  * g_socket_connect:
  * @socket: a #GSocket.
  * @address: a #GSocketAddress specifying the remote address.
- * @cancellable: a %GCancellable or %NULL
  * @error: #GError for error reporting, or %NULL to ignore.
  *
  * Connect the socket to the specified remote address.
@@ -1485,7 +1466,6 @@ g_socket_accept (GSocket       *socket,
 gboolean
 g_socket_connect (GSocket         *socket,
 		  GSocketAddress  *address,
-		  GCancellable    *cancellable,
 		  GError         **error)
 {
   struct sockaddr_storage buffer;
@@ -1516,12 +1496,11 @@ g_socket_connect (GSocket         *socket,
 	    {
 	      if (socket->priv->blocking)
 		{
-		  if (g_socket_condition_wait (socket, G_IO_OUT, cancellable, error))
-		    {
-		      if (g_socket_check_connect_result (socket, error))
-			break;
-		    }
-		  g_prefix_error (error, _("Error connecting: "));
+		  g_socket_condition_wait (socket, G_IO_OUT, NULL, NULL);
+		  if (g_socket_check_connect_result (socket, error))
+		    break;
+		  else
+		    g_prefix_error (error, _("Error connecting: "));
 		}
 	      else
                 g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_PENDING,
@@ -1589,7 +1568,6 @@ g_socket_check_connect_result (GSocket  *socket,
  * @buffer: a buffer to read data into (which should be at least @size
  *     bytes long).
  * @size: the number of bytes you want to read from the socket
- * @cancellable: a %GCancellable or %NULL
  * @error: #GError for error reporting, or %NULL to ignore.
  *
  * Receive data (up to @size bytes) from a socket. This is mainly used by
@@ -1620,11 +1598,10 @@ g_socket_check_connect_result (GSocket  *socket,
  * Since: 2.22
  */
 gssize
-g_socket_receive (GSocket       *socket,
-		  gchar         *buffer,
-		  gsize          size,
-		  GCancellable  *cancellable,
-		  GError       **error)
+g_socket_receive (GSocket  *socket,
+		  gchar    *buffer,
+		  gsize     size,
+		  GError  **error)
 {
   gssize ret;
 
@@ -1633,14 +1610,11 @@ g_socket_receive (GSocket       *socket,
   if (!check_socket (socket, error))
     return -1;
 
-  if (g_cancellable_set_error_if_cancelled (cancellable, error))
-    return -1;
-
   while (1)
     {
       if (socket->priv->blocking &&
 	  !g_socket_condition_wait (socket,
-				    G_IO_IN, cancellable, error))
+				    G_IO_IN, NULL, error))
 	return -1;
 
       if ((ret = recv (socket->priv->fd, buffer, size, 0)) < 0)
@@ -1685,7 +1659,6 @@ g_socket_receive (GSocket       *socket,
  * @buffer: a buffer to read data into (which should be at least @size
  *     bytes long).
  * @size: the number of bytes you want to read from the socket
- * @cancellable: a %GCancellable or %NULL
  * @error: #GError for error reporting, or %NULL to ignore.
  *
  * Receive data (up to @size bytes) from a socket.
@@ -1705,7 +1678,6 @@ g_socket_receive_from (GSocket         *socket,
 		       GSocketAddress **address,
 		       gchar           *buffer,
 		       gsize            size,
-		       GCancellable    *cancellable,
 		       GError         **error)
 {
   GInputVector v;
@@ -1717,26 +1689,14 @@ g_socket_receive_from (GSocket         *socket,
 				   address,
 				   &v, 1,
 				   NULL, 0, NULL,
-				   cancellable,
 				   error);
 }
 
-/* Although we ignore SIGPIPE, gdb will still stop if the app receives
- * one, which can be confusing and annoying. So if possible, we want
- * to suppress the signal entirely.
- */
-#ifdef MSG_NOSIGNAL
-#define G_SOCKET_DEFAULT_SEND_FLAGS MSG_NOSIGNAL
-#else
-#define G_SOCKET_DEFAULT_SEND_FLAGS 0
-#endif
-
 /**
  * g_socket_send:
  * @socket: a #GSocket
  * @buffer: the buffer containing the data to send.
  * @size: the number of bytes to send
- * @cancellable: a %GCancellable or %NULL
  * @error: #GError for error reporting, or %NULL to ignore.
  *
  * Tries to send @size bytes from @buffer on the socket. This is
@@ -1760,11 +1720,10 @@ g_socket_receive_from (GSocket         *socket,
  * Since: 2.22
  */
 gssize
-g_socket_send (GSocket       *socket,
-	       const gchar   *buffer,
-	       gsize          size,
-	       GCancellable  *cancellable,
-	       GError       **error)
+g_socket_send (GSocket      *socket,
+	       const gchar  *buffer,
+	       gsize         size,
+	       GError      **error)
 {
   gssize ret;
 
@@ -1773,17 +1732,14 @@ g_socket_send (GSocket       *socket,
   if (!check_socket (socket, error))
     return -1;
 
-  if (g_cancellable_set_error_if_cancelled (cancellable, error))
-    return -1;
-
   while (1)
     {
       if (socket->priv->blocking &&
 	  !g_socket_condition_wait (socket,
-				    G_IO_OUT, cancellable, error))
+				    G_IO_OUT, NULL, error))
 	return -1;
 
-      if ((ret = send (socket->priv->fd, buffer, size, G_SOCKET_DEFAULT_SEND_FLAGS)) < 0)
+      if ((ret = send (socket->priv->fd, buffer, size, 0)) < 0)
 	{
 	  int errsv = get_socket_errno ();
 
@@ -1824,7 +1780,6 @@ g_socket_send (GSocket       *socket,
  * @address: a #GSocketAddress, or %NULL
  * @buffer: the buffer containing the data to send.
  * @size: the number of bytes to send
- * @cancellable: a %GCancellable or %NULL
  * @error: #GError for error reporting, or %NULL to ignore.
  *
  * Tries to send @size bytes from @buffer to @address. If @address is
@@ -1843,7 +1798,6 @@ g_socket_send_to (GSocket         *socket,
 		  GSocketAddress  *address,
 		  const gchar     *buffer,
 		  gsize            size,
-		  GCancellable    *cancellable,
 		  GError         **error)
 {
   GOutputVector v;
@@ -1855,9 +1809,7 @@ g_socket_send_to (GSocket         *socket,
 				address,
 				&v, 1,
 				NULL, 0,
-				0,
-				cancellable,
-				error);
+				0, error);
 }
 
 /**
@@ -2008,6 +1960,14 @@ g_socket_close (GSocket  *socket,
       break;
     }
 
+#ifdef G_OS_WIN32
+  if (socket->priv->event != WSA_INVALID_EVENT)
+    {
+      WSACloseEvent (socket->priv->event);
+      socket->priv->event = WSA_INVALID_EVENT;
+    }
+#endif
+
   socket->priv->connected = FALSE;
   socket->priv->closed = TRUE;
 
@@ -2271,10 +2231,7 @@ winsock_finalize (GSource *source)
   g_object_unref (socket);
 
   if (winsock_source->cancellable)
-    {
-      g_cancellable_release_fd (winsock_source->cancellable);
-      g_object_unref (winsock_source->cancellable);
-    }
+    g_object_unref (winsock_source->cancellable);
 }
 
 static GSourceFuncs winsock_funcs =
@@ -2310,10 +2267,11 @@ winsock_source_new (GSocket      *socket,
   winsock_source->condition = condition;
   add_condition_watch (socket, &winsock_source->condition);
 
-  if (g_cancellable_make_pollfd (cancellable,
-                                 &winsock_source->cancel_pollfd))
+  if (cancellable)
     {
       winsock_source->cancellable = g_object_ref (cancellable);
+      g_cancellable_make_pollfd (cancellable,
+				 &winsock_source->cancel_pollfd);
       g_source_add_poll (source, &winsock_source->cancel_pollfd);
     }
 
@@ -2464,8 +2422,11 @@ g_socket_condition_wait (GSocket       *socket,
     num_events = 0;
     events[num_events++] = socket->priv->event;
 
-    if (g_cancellable_make_pollfd (cancellable, &cancel_fd))
-      events[num_events++] = (WSAEVENT)cancel_fd.fd;
+    if (cancellable)
+      {
+	g_cancellable_make_pollfd (cancellable, &cancel_fd);
+	events[num_events++] = (WSAEVENT)cancel_fd.fd;
+      }
 
     current_condition = update_condition (socket);
     while ((condition & current_condition) == 0)
@@ -2489,8 +2450,6 @@ g_socket_condition_wait (GSocket       *socket,
 	current_condition = update_condition (socket);
       }
     remove_condition_watch (socket, &condition);
-    if (num_events > 1)
-      g_cancellable_release_fd (cancellable);
 
     return (condition & current_condition) != 0;
   }
@@ -2504,15 +2463,15 @@ g_socket_condition_wait (GSocket       *socket,
     poll_fd[0].events = condition;
     num = 1;
 
-    if (g_cancellable_make_pollfd (cancellable, &poll_fd[1]))
-      num++;
+    if (cancellable)
+      {
+	g_cancellable_make_pollfd (cancellable, &poll_fd[1]);
+	num++;
+      }
 
     do
       result = g_poll (poll_fd, num, -1);
     while (result == -1 && get_socket_errno () == EINTR);
-    
-    if (num > 1)
-      g_cancellable_release_fd (cancellable);
 
     return cancellable == NULL ||
       !g_cancellable_set_error_if_cancelled (cancellable, error);
@@ -2530,7 +2489,6 @@ g_socket_condition_wait (GSocket       *socket,
  *   %NULL.
  * @num_messages: number of elements in @messages, or -1.
  * @flags: an int containing #GSocketMsgFlags flags
- * @cancellable: a %GCancellable or %NULL
  * @error: #GError for error reporting, or %NULL to ignore.
  *
  * Send data to @address on @socket.  This is the most complicated and
@@ -2584,7 +2542,6 @@ g_socket_send_message (GSocket                *socket,
 		       GSocketControlMessage **messages,
 		       gint                    num_messages,
 		       gint                    flags,
-		       GCancellable           *cancellable,
 		       GError                **error)
 {
   GOutputVector one_vector;
@@ -2593,9 +2550,6 @@ g_socket_send_message (GSocket                *socket,
   if (!check_socket (socket, error))
     return -1;
 
-  if (g_cancellable_set_error_if_cancelled (cancellable, error))
-    return -1;
-
   if (num_vectors == -1)
     {
       for (num_vectors = 0;
@@ -2635,11 +2589,6 @@ g_socket_send_message (GSocket                *socket,
 	if (!g_socket_address_to_native (address, msg.msg_name, msg.msg_namelen, error))
 	  return -1;
       }
-    else
-      {
-	msg.msg_name = NULL;
-	msg.msg_namelen = 0;
-      }
 
     /* iov */
     {
@@ -2699,10 +2648,10 @@ g_socket_send_message (GSocket                *socket,
       {
 	if (socket->priv->blocking &&
 	    !g_socket_condition_wait (socket,
-				      G_IO_OUT, cancellable, error))
+				      G_IO_OUT, NULL, error))
 	  return -1;
 
-	result = sendmsg (socket->priv->fd, &msg, flags | G_SOCKET_DEFAULT_SEND_FLAGS);
+	result = sendmsg (socket->priv->fd, &msg, flags);
 	if (result < 0)
 	  {
 	    int errsv = get_socket_errno ();
@@ -2767,7 +2716,7 @@ g_socket_send_message (GSocket                *socket,
       {
 	if (socket->priv->blocking &&
 	    !g_socket_condition_wait (socket,
-				      G_IO_OUT, cancellable, error))
+				      G_IO_OUT, NULL, error))
 	  return -1;
 
 	if (address)
@@ -2821,7 +2770,6 @@ g_socket_send_message (GSocket                *socket,
  * @num_messages: a pointer which will be filled with the number of
  *    elements in @messages, or %NULL
  * @flags: a pointer to an int containing #GSocketMsgFlags flags
- * @cancellable: a %GCancellable or %NULL
  * @error: a #GError pointer, or %NULL
  *
  * Receive data from a socket.  This is the most complicated and
@@ -2892,7 +2840,6 @@ g_socket_receive_message (GSocket                 *socket,
 			  GSocketControlMessage ***messages,
 			  gint                    *num_messages,
 			  gint                    *flags,
-			  GCancellable            *cancellable,
 			  GError                 **error)
 {
   GInputVector one_vector;
@@ -2901,9 +2848,6 @@ g_socket_receive_message (GSocket                 *socket,
   if (!check_socket (socket, error))
     return -1;
 
-  if (g_cancellable_set_error_if_cancelled (cancellable, error))
-    return -1;
-
   if (num_vectors == -1)
     {
       for (num_vectors = 0;
@@ -2981,7 +2925,7 @@ g_socket_receive_message (GSocket                 *socket,
       {
 	if (socket->priv->blocking &&
 	    !g_socket_condition_wait (socket,
-				      G_IO_IN, cancellable, error))
+				      G_IO_IN, NULL, error))
 	  return -1;
 
 	result = recvmsg (socket->priv->fd, &msg, msg.msg_flags);
@@ -3044,8 +2988,9 @@ g_socket_receive_message (GSocket                 *socket,
 	  if (index == allocated)
 	    {
 	      /* estimated 99% case: exactly 1 control message */
-	      allocated = MAX (allocated * 2, 1);
+	      allocated = MIN (allocated * 2, 1);
 	      my_messages = g_new (GSocketControlMessage *, (allocated + 1));
+	      allocated = 1;
 	    }
 
 	  my_messages[index++] = message;
@@ -3108,7 +3053,7 @@ g_socket_receive_message (GSocket                 *socket,
       {
 	if (socket->priv->blocking &&
 	    !g_socket_condition_wait (socket,
-				      G_IO_IN, cancellable, error))
+				      G_IO_IN, NULL, error))
 	  return -1;
 
 	addrlen = sizeof addr;
